Fix typo in function name (#136273)

Rename `removeIOSimulator` to `removeIOSSimulator`.
diff --git a/dev/devicelab/bin/tasks/hot_mode_dev_cycle_ios_simulator.dart b/dev/devicelab/bin/tasks/hot_mode_dev_cycle_ios_simulator.dart
index d41e414..971a9ca 100644
--- a/dev/devicelab/bin/tasks/hot_mode_dev_cycle_ios_simulator.dart
+++ b/dev/devicelab/bin/tasks/hot_mode_dev_cycle_ios_simulator.dart
@@ -19,7 +19,7 @@
         await createHotModeTest(deviceIdOverride: deviceId, checkAppRunningOnLocalDevice: true)();
       });
     } finally {
-      await removeIOSimulator(simulatorDeviceId);
+      await removeIOSSimulator(simulatorDeviceId);
     }
 
     return TaskResult.success(null);
diff --git a/dev/devicelab/bin/tasks/module_test_ios.dart b/dev/devicelab/bin/tasks/module_test_ios.dart
index cd6218e..4de6fb8 100644
--- a/dev/devicelab/bin/tasks/module_test_ios.dart
+++ b/dev/devicelab/bin/tasks/module_test_ios.dart
@@ -663,7 +663,7 @@
     } catch (e) {
       return TaskResult.failure(e.toString());
     } finally {
-      unawaited(removeIOSimulator(simulatorDeviceId));
+      unawaited(removeIOSSimulator(simulatorDeviceId));
       rmTree(tempDir);
     }
   });
diff --git a/dev/devicelab/bin/tasks/native_assets_ios_simulator.dart b/dev/devicelab/bin/tasks/native_assets_ios_simulator.dart
index 7357945..8b7c463 100644
--- a/dev/devicelab/bin/tasks/native_assets_ios_simulator.dart
+++ b/dev/devicelab/bin/tasks/native_assets_ios_simulator.dart
@@ -24,7 +24,7 @@
         },
       );
     } finally {
-      await removeIOSimulator(simulatorDeviceId);
+      await removeIOSSimulator(simulatorDeviceId);
     }
     return TaskResult.success(null);
   });
diff --git a/dev/devicelab/lib/tasks/plugin_tests.dart b/dev/devicelab/lib/tasks/plugin_tests.dart
index ec795eb..b4cd934 100644
--- a/dev/devicelab/lib/tasks/plugin_tests.dart
+++ b/dev/devicelab/lib/tasks/plugin_tests.dart
@@ -278,7 +278,7 @@
             }
           });
         } finally {
-          await removeIOSimulator(simulatorDeviceId);
+          await removeIOSSimulator(simulatorDeviceId);
         }
       case 'linux':
         if (await exec(
diff --git a/dev/devicelab/lib/framework/ios.dart b/dev/devicelab/lib/framework/ios.dart
index 61f8bf3..c663c44 100644
--- a/dev/devicelab/lib/framework/ios.dart
+++ b/dev/devicelab/lib/framework/ios.dart
@@ -50,7 +50,7 @@
 /// Creates and boots a new simulator, passes the new simulator's identifier to
 /// `testFunction`.
 ///
 /// Remember to call removeIOSimulator in the test teardown.
 Future<void> testWithNewIOSSimulator(
   String deviceName,
   SimulatorFunction testFunction, {
@@ -110,7 +110,7 @@
 }
 
 /// Shuts down and deletes simulator with deviceId.
-Future<void> removeIOSimulator(String? deviceId) async {
+Future<void> removeIOSSimulator(String? deviceId) async {
   if (deviceId != null && deviceId != '') {
     await eval(
       'xcrun',
@@ -50,7 +50,7 @@
 /// `testFunction`.
 ///
-/// Remember to call removeIOSimulator in the test teardown.
+/// Remember to call removeIOSSimulator in the test teardown.
 Future<void> testWithNewIOSSimulator(
   String deviceName,